##  Applications
The name of a SaaS component is based on its current name at the time of collection, regardless of any previous names. If SaaS components have a generalized name, the provider's name is added as a prefix to the component.
Naming Conventions for Applications Naming Convention | Notes
---|---
Non-generalized SaaS component: Name of the application | Generalized names are common names used by providers for their applications.
Generalized SaaS component: Provider name + name of the application


